pytest\_helpers\_namespace package
==================================

.. automodule:: pytest_helpers_namespace
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

pytest\_helpers\_namespace.plugin module
----------------------------------------

.. automodule:: pytest_helpers_namespace.plugin
   :members:
   :undoc-members:
   :show-inheritance:

pytest\_helpers\_namespace.version module
-----------------------------------------

.. automodule:: pytest_helpers_namespace.version
   :members:
   :undoc-members:
   :show-inheritance:
